#!/usr/bin/env python

import sys, StringIO, html5lib
from html5lib import treebuilders, treewalkers, serializer

prune = False

def forall(p, l):
  return reduce(lambda r, x: r and p(x), l, True)

def is_token_tag(token):
  if token["type"] in ["StartTag", "EndTag", "EmptyTag"]:
    return True
  else:
    return False

def check_token(token):
  global prune
  formatting = set([u'b', u'big', u'em', u'i', u'small', u'strong', \
                u'sub', u'sup', u'ins', u'del', u'u', u's', \
                u'code', u'tt', u'samp', u'q', u'cite'])
  headers = set([u'h1', u'h2', u'h3', u'h4', u'h5', u'h6'])
  layout = set([u'center', u'p', u'br', u'table', u'tr', u'td'])
  misc = set([u'a', u'img', u'div'])
  attributes = [u'class', u'href', u'width', u'height', u'color', \
                u'title', u'id', u'src', u'name', u'alt']
  safetags = formatting | headers | layout | misc

  if token["name"] not in safetags: 
    if token["type"] == "StartTag":
      prune = True
    elif token["type"] == "EndTag":
      prune = False
    return False
  else:
    if forall(lambda x: x[0] in attributes, token["data"]):
      return True
    else:
      return False

def is_token_safe(token):
  global prune
  if is_token_tag(token):
    return check_token(token)
  elif token["type"] == "Characters" and (not prune):
    return True
  else:
    return False

data = ''.join(map(lambda x: x.strip(), sys.stdin.readlines()))
f = StringIO.StringIO([data])
parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("dom"))
document = parser.parse(f)
walker = treewalkers.getTreeWalker("dom")
stream = walker(document)

safe_stream = [token for token in stream if is_token_safe(token)]

s = serializer.htmlserializer.HTMLSerializer(omit_optional_tags=False)
output_generator = s.serialize(safe_stream)

for x in output_generator:
  print x.encode("cp1252").decode('string_escape')
